# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.179.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class InvoiceActionType(str, Enum):
    """
    InvoiceActionType
    """

    """
    allowed enum values
    """
    GENERATED = 'GENERATED'
    EDITED = 'EDITED'
    SENT = 'SENT'
    RESENT = 'RESENT'
    MARKED_AS_PAID = 'MARKED_AS_PAID'

    @classmethod
    def from_json(cls, json_str: str) -> InvoiceActionType:
        """Create an instance of InvoiceActionType from a JSON string"""
        return InvoiceActionType(json.loads(json_str))


