# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.179.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import empire_platform_api_public_client
from empire_platform_api_public_client.api.default_nomination_api import DefaultNominationApi  # noqa: E501
from empire_platform_api_public_client.rest import ApiException


class TestDefaultNominationApi(unittest.TestCase):
    """DefaultNominationApi unit test stubs"""

    def setUp(self):
        self.api = empire_platform_api_public_client.api.default_nomination_api.DefaultNominationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_default_nomination(self):
        """Test case for create_default_nomination

        """
        pass

    def test_delete_default_nomination(self):
        """Test case for delete_default_nomination

        """
        pass

    def test_get_default_nomination(self):
        """Test case for get_default_nomination

        """
        pass

    def test_get_default_nomination_options(self):
        """Test case for get_default_nomination_options

        """
        pass

    def test_get_default_nominations(self):
        """Test case for get_default_nominations

        """
        pass

    def test_update_default_nomination(self):
        """Test case for update_default_nomination

        """
        pass


if __name__ == '__main__':
    unittest.main()
